#!/bin/sh

# set & check where all the good stuff is
sbox=/scratchbox/users/$USER
utils=/scratchbox/tools/bin

if [ ! -d "$sbox" ]; then
	echo "ERROR: Scratchbox dir '$sbox' is missing."
	exit 1
fi
if [ ! -d "$sbox/$utils" ]; then
	echo "ERROR: Scratchbox dir '$sbox/$utils' is missing."
	exit 1
fi
if [ ! -c "$sbox/dev/zero" ] ; then
	echo "ERROR: /dev is probably missing.!"
	exit 1
fi


# go to scratchbox
cd $sbox
if [ $? != 0 ]; then
	echo "ERROR: Could not change to '$sbox' directory."
 	exit 1
fi

# check shell
if [ ! -x "bin/sh" ]; then
	echo "ERROR: Sandbox shell '$sbox/$utils/sh' missing."
	exit 1
fi

# check chroot-uid
CHROOT="/scratchbox/sbin/chroot-uid"
if [ ! -x "$CHROOT" ]; then
	echo "ERROR: '$CHROOT' is missing."
	exit 1
fi
if [ ! -u "$CHROOT" ]; then
	echo "ERROR: '$CHROOT' is not suid ROOT."
	exit 1
fi

# command to run services in chroot jail
RUN="$CHROOT $PWD"

# rairai
if [ ! -f "$sbox/etc/nsswitch.conf" ] ; then
	cp /etc/nsswitch.conf "$sbox/etc/"
fi

if [ ! -f "$sbox/etc/resolv.conf" ] ; then
	cp /etc/resolv.conf "$sbox/etc/"
fi

if [ ! -f "$sbox/etc/passwd" ] ; then
	echo "$USER::$UID:$UID::$HOME:/bin/sh" > "$sbox/etc/passwd"
fi

if [ ! -d "$sbox/$HOME/.terminfo" ] ; then
	mkdir "$sbox/$HOME/.terminfo"
	cp -r /usr/share/terminfo/* "$sbox/$HOME/.terminfo/"
fi

# print sbox instructions
echo "
  Welcome to *Scratchbox*, the cross-compilation SDK!

Scratchbox is a self-contained mini-distribution that contains all the
tools needed to configure and cross-compile Open Source software using
GNU make and *autoconf*.  All the software configuration, compilation
and installation is done in a sandbox environment exactly like on your
target device.  This is achieved by using chroot or UML (User Mode
Linux) to limit system visibility for configuration scripts you run
from this shell, into what exists inside the scratchbox sandbox.

The Scrachbox utilities are:
  sbox-config -- Change your compilation target
  
"

# Select current target CPU
if [ ! -L "$sbox/targets/links/scratchbox.config" ]; then
	$RUN bin/sh -l $utils/sbox-config --create-target=PC --compiler-name=i386-gcc-3.2.1
	$RUN bin/sh -l $utils/sbox-config --select-target=PC
fi


# Warn about missing exports
ARMIP="[ip of your cpuTransp device]"
TARGET=`ls -al $sbox/targets/links/scratchbox.config | rev | cut -d "/" -f 1 | rev | sed 's/.config$//'`

ROOT_EXPORT=`cat /etc/exports | grep "^$sbox/targets/$TARGET"`
if [ "x$ROOT_EXPORT" = "x" ] ; then
	echo "WARNING: You don't have root export for your target needed by cpuTransparency!"
	echo "  Add following line to /etc/exports (and remember to restart nfs-server) : "
	echo
	echo "  $sbox/targets/$TARGET $ARMIP(rw,all_squash,anonuid=$UID,anongid=$GROUPS)"
	echo 
fi

HOME_EXPORT=`cat /etc/exports | grep "^$sbox/home"`
if [ "x$HOME_EXPORT" = "x" ] ; then
	echo "WARNING: You don't have home export needed by cpuTransparency!"
	echo "  Add following line to /etc/exports (and remember to restart nfs-server) : "
	echo
	echo "  $sbox/home $ARMIP(rw,all_squash,anonuid=$UID,anongid=$GROUPS)"
	echo
fi


#  sbox-image -- Create target root image


# automatic scratchbox command execution
if [ ! -z $1 ]; then
	argc="-c $*"
else
	args=""
fi

# run SDK shell
$RUN bin/sh -l $args

# kill the script process group (everything run from this script)
kill -- -$$

